module RightImage

  RELEASE_LEVELS = ["Alpha", "Beta", "Ga"]
  HIDDEN_RELEASE_LEVELS = [ "Ga" ]

  class Util
    
    def self.create_image_name(image_prefix, os_name, os_version, os_arch, os_modifier, right_image_version, right_image_build = nil, image_build_number = nil, virtualization_type = nil, storage_type = nil, release_level = nil, suffix = nil)

      image_name = "#{image_prefix}_#{os_name}_#{os_version.to_s}_#{os_arch}"

      unless os_modifier.nil? || os_modifier.empty?
        image_name << "_#{os_modifier}"
      end

      package_version = rightimage_version(right_image_version, right_image_build, image_build_number)
      image_name << "_v#{package_version}"
      image_name << "_#{virtualization_type}" if !virtualization_type.to_s.empty? && virtualization_type.downcase != "pvm"
      image_name << "_#{storage_type}" if !storage_type.to_s.empty? && storage_type.downcase !~ /s3|instancestore/

      if release_level
        level = release_level.capitalize
        raise "ERROR: release_level must be set to 'Alpha', 'GA', or 'Beta'" unless RELEASE_LEVELS.include?(level)
        image_name << "_#{level}" unless HIDDEN_RELEASE_LEVELS.include?(level)
      end

      image_name << "_#{suffix.capitalize}" unless suffix.to_s.empty?

      image_name
    end    
    
    def self.rightimage_package_version(version, build_number=nil)
      unless version.to_s =~ /^[0-9]*\.[0-9]*$/ or
             version.to_s =~ /^2\d\d\d\.\d\d.\d\d$/
        raise ArgumentError, "rightimage version must be a 'N.N' or 'YYYY.MM.DD' format." 
      end
      ver = "#{version.to_s}"
      ver << ".#{build_number}" if build_number.to_s =~ /./
      ver
    end

    def self.rightimage_version(package_version, package_build=nil, image_build = nil)
      ver = rightimage_package_version(package_version, package_build)
      ver << ".#{image_build}" unless image_build.to_i == 0
      ver
    end

    def self.create_mci_name(image_prefix, os_name, os_version, os_arch, os_modifier, right_image_version, virtualization_type, storage_type = nil, release_level = nil, suffix = nil)
      create_image_name(image_prefix, os_name, os_version, os_arch, os_modifier, right_image_version, nil, nil, virtualization_type, storage_type, release_level, suffix)
    end
      
      
  end
end
